friend package
==============

friend\.collections module
--------------------------

.. automodule:: friend.collections
    :members:
    :undoc-members:
    :show-inheritance:

friend\.net module
------------------

.. automodule:: friend.net
    :members:
    :undoc-members:
    :show-inheritance:

friend\.strings module
----------------------

.. automodule:: friend.strings
    :members:
    :undoc-members:
    :show-inheritance:

friend\.utils module
--------------------

.. automodule:: friend.utils
    :members:
    :undoc-members:
    :show-inheritance:
